==> PyCIM-14.15.1.tar.gz: PyCIM-14.15.1/CIM14/IEC61970/Generation/GenerationDynamics/__init__.py <==
# Copyright (C) 2010 Richard Lincoln
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA, USA

"""The Generation Dynamics package contains prime movers, such as turbines and boilers, which are needed for simulation and educational purposes.
"""

nsPrefix = "cimGenerationDynamics"
nsURI = "http://iec.ch/TC57/2009/CIM-schema-cim14#GenerationDynamics"

from CIM14.IEC61970.Generation.GenerationDynamics.SteamSupply import SteamSupply
from CIM14.IEC61970.Generation.GenerationDynamics.FossilSteamSupply import FossilSteamSupply
from CIM14.IEC61970.Generation.GenerationDynamics.HeatRecoveryBoiler import HeatRecoveryBoiler
from CIM14.IEC61970.Generation.GenerationDynamics.PWRSteamSupply import PWRSteamSupply
from CIM14.IEC61970.Generation.GenerationDynamics.PrimeMover import PrimeMover
from CIM14.IEC61970.Generation.GenerationDynamics.Supercritical import Supercritical
from CIM14.IEC61970.Generation.GenerationDynamics.CombustionTurbine import CombustionTurbine
from CIM14.IEC61970.Generation.GenerationDynamics.HydroTurbine import HydroTurbine
from CIM14.IEC61970.Generation.GenerationDynamics.Subcritical import Subcritical
from CIM14.IEC61970.Generation.GenerationDynamics.CTTempActivePowerCurve import CTTempActivePowerCurve
from CIM14.IEC61970.Generation.GenerationDynamics.SteamTurbine import SteamTurbine
from CIM14.IEC61970.Generation.GenerationDynamics.DrumBoiler import DrumBoiler
from CIM14.IEC61970.Generation.GenerationDynamics.BWRSteamSupply import BWRSteamSupply

==> PyCIM-14.15.2.tar.gz: PyCIM-14.15.2/CIM14/IEC61970/Generation/GenerationDynamics/__init__.py <==
# Copyright (C) 2010 Richard Lincoln
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA, USA

"""The Generation Dynamics package contains prime movers, such as turbines and boilers, which are needed for simulation and educational purposes.
"""

nsPrefix = "cimGenerationDynamics"
nsURI = "http://iec.ch/TC57/2009/CIM-schema-cim14#GenerationDynamics"

from CIM14.IEC61970.Generation.GenerationDynamics.SteamSupply import SteamSupply
from CIM14.IEC61970.Generation.GenerationDynamics.FossilSteamSupply import FossilSteamSupply
from CIM14.IEC61970.Generation.GenerationDynamics.HeatRecoveryBoiler import HeatRecoveryBoiler
from CIM14.IEC61970.Generation.GenerationDynamics.PWRSteamSupply import PWRSteamSupply
from CIM14.IEC61970.Generation.GenerationDynamics.PrimeMover import PrimeMover
from CIM14.IEC61970.Generation.GenerationDynamics.Supercritical import Supercritical
from CIM14.IEC61970.Generation.GenerationDynamics.CombustionTurbine import CombustionTurbine
from CIM14.IEC61970.Generation.GenerationDynamics.HydroTurbine import HydroTurbine
from CIM14.IEC61970.Generation.GenerationDynamics.Subcritical import Subcritical
from CIM14.IEC61970.Generation.GenerationDynamics.CTTempActivePowerCurve import CTTempActivePowerCurve
from CIM14.IEC61970.Generation.GenerationDynamics.SteamTurbine import SteamTurbine
from CIM14.IEC61970.Generation.GenerationDynamics.DrumBoiler import DrumBoiler
from CIM14.IEC61970.Generation.GenerationDynamics.BWRSteamSupply import BWRSteamSupply

class BoilerControlMode(str):
    """Boiler control mode.
    Values are: following, coordinated
    """
    pass

class TurbineType(str):
    """Type of turbine.
    Values are: francis, pelton, kaplan
    """
    pass
